#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'opengl.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENGL_H
#define UI_OPENGL_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_OpenGL
{
public:
    QVBoxLayout *vboxLayout;
    QTreeWidget *glinfoTreeWidget;

    void setupUi(QWidget *OpenGL)
    {
        if (OpenGL->objectName().isEmpty())
            OpenGL->setObjectName(QStringLiteral("OpenGL"));
        OpenGL->resize(400, 397);
        vboxLayout = new QVBoxLayout(OpenGL);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        glinfoTreeWidget = new QTreeWidget(OpenGL);
        glinfoTreeWidget->setObjectName(QStringLiteral("glinfoTreeWidget"));

        vboxLayout->addWidget(glinfoTreeWidget);


        retranslateUi(OpenGL);

        QMetaObject::connectSlotsByName(OpenGL);
    } // setupUi

    void retranslateUi(QWidget *OpenGL)
    {
        QTreeWidgetItem *___qtreewidgetitem = glinfoTreeWidget->headerItem();
        ___qtreewidgetitem->setText(0, tr2i18n("1", Q_NULLPTR));
        Q_UNUSED(OpenGL);
    } // retranslateUi

};

namespace Ui {
    class OpenGL: public Ui_OpenGL {};
} // namespace Ui

QT_END_NAMESPACE

#endif // OPENGL_H

