#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'Module.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MODULE_H
#define UI_MODULE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Module
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QSpacerItem *verticalSpacer_6;
    QLabel *nameVersionLabel;
    QLabel *variantLabel;
    QLabel *urlLabel;
    QSpacerItem *verticalSpacer_5;
    QLabel *plasma;
    QSpacerItem *horizontalSpacer_7;
    QWidget *widget;
    QHBoxLayout *horizontalLayout;
    QLabel *logoLabel;
    QSpacerItem *horizontalSpacer;
    QLabel *memoryLabel;
    QLabel *plasmaLabel;
    QLabel *memory;
    QSpacerItem *verticalSpacer;
    QLabel *processor;
    QLabel *label_2;
    QLabel *kernelLabel;
    QLabel *qtLabel;
    QSpacerItem *horizontalSpacer_4;
    QSpacerItem *verticalSpacer_4;
    QLabel *qt;
    QLabel *bitsLabel;
    QLabel *label;
    QLabel *label_3;
    QSpacerItem *verticalSpacer_2;
    QLabel *kernel;
    QSpacerItem *verticalSpacer_3;
    QLabel *processorLabel;
    QLabel *frameworksLabelKey;
    QLabel *frameworksLabel;

    void setupUi(QWidget *Module)
    {
        if (Module->objectName().isEmpty())
            Module->setObjectName(QStringLiteral("Module"));
        Module->resize(643, 586);
        gridLayout = new QGridLayout(Module);
        gridLayout->setObjectName(QStringLiteral("gridLayout"));
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Preferred);

        verticalLayout->addItem(verticalSpacer_6);

        nameVersionLabel = new QLabel(Module);
        nameVersionLabel->setObjectName(QStringLiteral("nameVersionLabel"));
        nameVersionLabel->setText(QStringLiteral("{NameVersionLabel}"));

        verticalLayout->addWidget(nameVersionLabel);

        variantLabel = new QLabel(Module);
        variantLabel->setObjectName(QStringLiteral("variantLabel"));

        verticalLayout->addWidget(variantLabel);

        urlLabel = new QLabel(Module);
        urlLabel->setObjectName(QStringLiteral("urlLabel"));
        urlLabel->setText(QStringLiteral("{UrlLabel}"));
        urlLabel->setOpenExternalLinks(true);

        verticalLayout->addWidget(urlLabel);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Preferred);

        verticalLayout->addItem(verticalSpacer_5);


        gridLayout->addLayout(verticalLayout, 1, 3, 1, 2);

        plasma = new QLabel(Module);
        plasma->setObjectName(QStringLiteral("plasma"));
        plasma->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(plasma, 5, 1, 1, 1);

        horizontalSpacer_7 = new QSpacerItem(215, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_7, 8, 4, 1, 1);

        widget = new QWidget(Module);
        widget->setObjectName(QStringLiteral("widget"));
        horizontalLayout = new QHBoxLayout(widget);
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        logoLabel = new QLabel(widget);
        logoLabel->setObjectName(QStringLiteral("logoLabel"));
        logoLabel->setText(QStringLiteral("{LogoLabel}"));
        logoLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        horizontalLayout->addWidget(logoLabel);

        horizontalSpacer = new QSpacerItem(4, 0, QSizePolicy::Fixed, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addWidget(widget, 1, 1, 1, 1);

        memoryLabel = new QLabel(Module);
        memoryLabel->setObjectName(QStringLiteral("memoryLabel"));
        memoryLabel->setText(QStringLiteral("{MemoryAmount}"));

        gridLayout->addWidget(memoryLabel, 13, 3, 1, 1);

        plasmaLabel = new QLabel(Module);
        plasmaLabel->setObjectName(QStringLiteral("plasmaLabel"));
        plasmaLabel->setText(QStringLiteral("{KDEVersion}"));

        gridLayout->addWidget(plasmaLabel, 5, 3, 1, 1);

        memory = new QLabel(Module);
        memory->setObjectName(QStringLiteral("memory"));
        memory->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(memory, 13, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout->addItem(verticalSpacer, 14, 3, 1, 1);

        processor = new QLabel(Module);
        processor->setObjectName(QStringLiteral("processor"));
        processor->setText(QStringLiteral("Processor:"));
        processor->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(processor, 12, 1, 1, 1);

        label_2 = new QLabel(Module);
        label_2->setObjectName(QStringLiteral("label_2"));
        QFont font;
        font.setBold(true);
        font.setWeight(75);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 3, 3, 1, 1);

        kernelLabel = new QLabel(Module);
        kernelLabel->setObjectName(QStringLiteral("kernelLabel"));
        kernelLabel->setText(QStringLiteral("{KernelName}"));

        gridLayout->addWidget(kernelLabel, 8, 3, 1, 1);

        qtLabel = new QLabel(Module);
        qtLabel->setObjectName(QStringLiteral("qtLabel"));
        qtLabel->setText(QStringLiteral("{QtVersion}"));

        gridLayout->addWidget(qtLabel, 7, 3, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(215, 17, QSizePolicy::Expanding, QSizePolicy::Minimum);

        gridLayout->addItem(horizontalSpacer_4, 8, 0, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 24, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(verticalSpacer_4, 10, 3, 1, 1);

        qt = new QLabel(Module);
        qt->setObjectName(QStringLiteral("qt"));
        qt->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(qt, 7, 1, 1, 1);

        bitsLabel = new QLabel(Module);
        bitsLabel->setObjectName(QStringLiteral("bitsLabel"));
        bitsLabel->setText(QStringLiteral("{QtArchitecutre}"));

        gridLayout->addWidget(bitsLabel, 9, 3, 1, 1);

        label = new QLabel(Module);
        label->setObjectName(QStringLiteral("label"));
        label->setFont(font);
        label->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(label, 11, 3, 1, 1);

        label_3 = new QLabel(Module);
        label_3->setObjectName(QStringLiteral("label_3"));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 9, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 24, QSizePolicy::Minimum, QSizePolicy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 2, 3, 1, 1);

        kernel = new QLabel(Module);
        kernel->setObjectName(QStringLiteral("kernel"));
        kernel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(kernel, 8, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 24, QSizePolicy::Minimum, QSizePolicy::Maximum);

        gridLayout->addItem(verticalSpacer_3, 0, 3, 1, 1);

        processorLabel = new QLabel(Module);
        processorLabel->setObjectName(QStringLiteral("processorLabel"));
        processorLabel->setText(QStringLiteral("{PrcoessorName}"));

        gridLayout->addWidget(processorLabel, 12, 3, 1, 1);

        frameworksLabelKey = new QLabel(Module);
        frameworksLabelKey->setObjectName(QStringLiteral("frameworksLabelKey"));
        frameworksLabelKey->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(frameworksLabelKey, 6, 1, 1, 1);

        frameworksLabel = new QLabel(Module);
        frameworksLabel->setObjectName(QStringLiteral("frameworksLabel"));
        frameworksLabel->setText(QStringLiteral("{FrameworksVersion}"));

        gridLayout->addWidget(frameworksLabel, 6, 3, 1, 1);


        retranslateUi(Module);

        QMetaObject::connectSlotsByName(Module);
    } // setupUi

    void retranslateUi(QWidget *Module)
    {
        variantLabel->setText(tr2i18n("{variantLabel}", Q_NULLPTR));
        plasma->setText(tr2i18n("KDE Plasma Version:", Q_NULLPTR));
        memory->setText(tr2i18n("Memory:", Q_NULLPTR));
        label_2->setText(tr2i18n("Software", Q_NULLPTR));
        qt->setText(tr2i18n("Qt Version:", Q_NULLPTR));
        label->setText(tr2i18n("Hardware", Q_NULLPTR));
        label_3->setText(tr2i18n("OS Type:", Q_NULLPTR));
        kernel->setText(tr2i18n("Kernel Version:", Q_NULLPTR));
        frameworksLabelKey->setText(tr2i18n("KDE Frameworks Version:", Q_NULLPTR));
        Q_UNUSED(Module);
    } // retranslateUi

};

namespace Ui {
    class Module: public Ui_Module {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MODULE_H

