/****************************************************************************
** Meta object code from reading C++ file 'devicelisting.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../src/kinfocenter-5.8.9/Modules/devinfo/devicelisting.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'devicelisting.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_DeviceListing_t {
    QByteArrayData data[10];
    char stringdata0[171];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_DeviceListing_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_DeviceListing_t qt_meta_stringdata_DeviceListing = {
    {
QT_MOC_LITERAL(0, 0, 13), // "DeviceListing"
QT_MOC_LITERAL(1, 14, 17), // "itemActivatedSlot"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(4, 50, 15), // "deviceAddedSlot"
QT_MOC_LITERAL(5, 66, 17), // "deviceRemovedSlot"
QT_MOC_LITERAL(6, 84, 22), // "collapseAllDevicesSlot"
QT_MOC_LITERAL(7, 107, 20), // "expandAllDevicesSlot"
QT_MOC_LITERAL(8, 128, 18), // "showAllDevicesSlot"
QT_MOC_LITERAL(9, 147, 23) // "showRelevantDevicesSlot"

    },
    "DeviceListing\0itemActivatedSlot\0\0"
    "QTreeWidgetItem*\0deviceAddedSlot\0"
    "deviceRemovedSlot\0collapseAllDevicesSlot\0"
    "expandAllDevicesSlot\0showAllDevicesSlot\0"
    "showRelevantDevicesSlot"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_DeviceListing[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x0a /* Public */,
       4,    1,   54,    2, 0x0a /* Public */,
       5,    1,   57,    2, 0x0a /* Public */,
       6,    0,   60,    2, 0x0a /* Public */,
       7,    0,   61,    2, 0x0a /* Public */,
       8,    0,   62,    2, 0x0a /* Public */,
       9,    0,   63,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void DeviceListing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        DeviceListing *_t = static_cast<DeviceListing *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->itemActivatedSlot((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< const int(*)>(_a[2]))); break;
        case 1: _t->deviceAddedSlot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 2: _t->deviceRemovedSlot((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->collapseAllDevicesSlot(); break;
        case 4: _t->expandAllDevicesSlot(); break;
        case 5: _t->showAllDevicesSlot(); break;
        case 6: _t->showRelevantDevicesSlot(); break;
        default: ;
        }
    }
}

const QMetaObject DeviceListing::staticMetaObject = {
    { &QTreeWidget::staticMetaObject, qt_meta_stringdata_DeviceListing.data,
      qt_meta_data_DeviceListing,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *DeviceListing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DeviceListing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_DeviceListing.stringdata0))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int DeviceListing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
